.. fast documentation master file, created by
   sphinx-quickstart on Tue Jan 17 17:38:31 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to FAST's documentation!
================================
**FAST** (Fourier domain Adaptive Optics Simulation Tool) is a simulation tool that utilises a Fourier domain AO model to enable rapid Monte Carlo characterisation of free space optical links between the Earth and satellites. This tool enables characterisation of the effect of turbulence with (or without) adaptive optics mitigation. For more details on the physics and modelling, see the paper https://doi.org/10.1364/OE.458659.

.. toctree::
   :maxdepth: 2
   :caption: Contents: 

   install
   configuration
   output
   

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
